Struct moose::host::SliceInfoElem
source · [−]Fields
start: isizeStart index; negative are counted from the back of the axis.
end: Option<isize>End index; negative are counted from the back of the axis; when not present the default is the full length of the axis.
step: Option<isize>Step size in elements; the default is 1, for every element.